==> contentsquare-3.8.0.tar.gz: android/src/main/kotlin/com/contentsquare/flutter/infrastructure/bridges/TelemetryInterfaceBridge.kt <==
package com.contentsquare.flutter.infrastructure.bridges

/**
 * Bridge to TelemetryInterface of contentsquare.
 */
internal interface TelemetryInterfaceBridge {
    /**
     * Set the version of XPF.
     *
     * @param version the current version.
     */
    fun telemetrySetXPFVersion(version: String)

    /**
     * Set the type of XPF.
     *
     * @param type the type of XPF
     */
    fun telemetrySetXPFType(type: String)

    /**
     * Collect custom telemetry
     *
     * @param value the value to collect
     */
    fun telemetryCollect(name: String, value: String)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [TelemetryInterfaceBridge].
         */
        fun default(): TelemetryInterfaceBridge {
            return TelemetryInterfaceBridgeImpl()
        }
    }
}

/**
 * Channel of method in the contentsquare sdk interfaces for telemetry.
 */
internal enum class TelemetryInterfaceChannel(val value: String) {
    /** channel/method called to set the XPF version */
    XPF_VERSION_SETTER("telemetrySetXPFVersion"),

    /** channel/method called to set the XPF type */
    XPF_TYPE_SETTER("telemetrySetXPFType"),

    /** channel/method called to collect other telemetry */
    COLLECT("telemetryCollect")
}

/**
 * Implementation of [TelemetryInterfaceBridge].
 *
 * @see TelemetryInterfaceBridge
 */
internal class TelemetryInterfaceBridgeImpl: TelemetryInterfaceBridge {
    private var telemetryInterfaceClass: Class<*>
    private var instance: Any
    init {
        telemetryInterfaceClass = getTelemetryInterfaceClass()
        instance = telemetryInterfaceClass.newInstance()
    }
    override fun telemetrySetXPFVersion(version: String) {
        telemetryInterfaceClass.getDeclaredMethod(TelemetryInterfaceChannel.XPF_VERSION_SETTER.value, Object::class.java).run {
            isAccessible = true
            invoke(instance, version)
        }
    }

    override fun telemetrySetXPFType(type: String) {
        telemetryInterfaceClass.getDeclaredMethod(TelemetryInterfaceChannel.XPF_TYPE_SETTER.value, Object::class.java).run {
            isAccessible = true
            invoke(instance, "flutter")
        }
    }

    override fun telemetryCollect(name: String, value: String) {
        telemetryInterfaceClass.getDeclaredMethod(TelemetryInterfaceChannel.COLLECT.value, String::class.java, Object::class.java).run {
            isAccessible = true
            invoke(instance, name, value)
        }
    }

    private fun getTelemetryInterfaceClass(): Class<*> {
        val className = "com.contentsquare.android.api.bridge.telemetry.TelemetryInterface"
        return Class.forName(className)
    }
}

==> contentsquare-3.9.0.tar.gz: android/src/main/kotlin/com/contentsquare/flutter/infrastructure/bridges/TelemetryInterfaceBridge.kt <==
package com.contentsquare.flutter.infrastructure.bridges

/**
 * Bridge to TelemetryInterface of contentsquare.
 */
internal interface TelemetryInterfaceBridge {
    /**
     * Set the version of XPF.
     *
     * @param version the current version.
     */
    fun telemetrySetXPFVersion(version: String)

    /**
     * Set the type of XPF.
     *
     * @param type the type of XPF
     */
    fun telemetrySetXPFType(type: String)

    /**
     * Collect custom telemetry
     *
     * @param value the value to collect
     */
    fun telemetryCollect(name: String, value: String)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [TelemetryInterfaceBridge].
         */
        fun default(): TelemetryInterfaceBridge {
            return TelemetryInterfaceBridgeImpl()
        }
    }
}

/**
 * Channel of method in the contentsquare sdk interfaces for telemetry.
 */
internal enum class TelemetryInterfaceChannel(val value: String) {
    /** channel/method called to set the XPF version */
    XPF_VERSION_SETTER("setXPFVersion"),

    /** channel/method called to set the XPF type */
    XPF_TYPE_SETTER("setXPFType"),

    /** channel/method called to collect other telemetry */
    COLLECT("telemetryCollect")
}

/**
 * Implementation of [TelemetryInterfaceBridge].
 *
 * @see TelemetryInterfaceBridge
 */
internal class TelemetryInterfaceBridgeImpl: TelemetryInterfaceBridge {
    private var telemetryInterfaceClass: Class<*>
    private var instance: Any
    init {
        telemetryInterfaceClass = getTelemetryInterfaceClass()
        instance = telemetryInterfaceClass.newInstance()
    }
    override fun telemetrySetXPFVersion(version: String) {
        telemetryInterfaceClass.getDeclaredMethod(TelemetryInterfaceChannel.XPF_VERSION_SETTER.value, Object::class.java).run {
            isAccessible = true
            invoke(instance, version)
        }
    }

    override fun telemetrySetXPFType(type: String) {
        telemetryInterfaceClass.getDeclaredMethod(TelemetryInterfaceChannel.XPF_TYPE_SETTER.value, Object::class.java).run {
            isAccessible = true
            invoke(instance, type)
        }
    }

    override fun telemetryCollect(name: String, value: String) {
        telemetryInterfaceClass.getDeclaredMethod(TelemetryInterfaceChannel.COLLECT.value, String::class.java, Object::class.java).run {
            isAccessible = true
            invoke(instance, name, value)
        }
    }

    private fun getTelemetryInterfaceClass(): Class<*> {
        val className = "com.contentsquare.android.api.bridge.telemetry.TelemetryInterface"
        return Class.forName(className)
    }
}
